==> sli-plots-0.0.26.tgz: package/addon/components/grid.js <==
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';

export default class LineChartComponent extends Component {
  @tracked svg;

  // Required params
  // @dimensions

  // Parameters w/ defaults
  get hasTopLine() {
    return !!this.args.hasTopLine;
  }

  get hasBottomLine() {
    return !!this.args.hasBottomLine;
  }

  get hasRightLine() {
    return !!this.args.hasRightLine;
  }

  get xLineStyle() {
    return this.args.xLineStyle
      ? this.args.xLineStyle
      : 'none';
  }

  get yLineStyle() {
    return this.args.yLineStyle
      ? this.args.yLineStyle
      : 'solid';
  }

  get strokeWidth() {
    return this.args.strokeWidth
      ? this.args.strokeWidth
      : '0.5';
  }

  get stroke() {
    return this.args.stroke
      ? this.args.stroke
      : 'lightgray';
  }

  get dashedSpacing() {
    return this.args.dashedSpacing
      ? this.args.dashedSpacing
      : '10,10';
  }

  // Number of X Lines
  get gridXCount() {
    return this.args.gridXCount
      ? this.args.gridXCount
      : 10;
  }

  // Number of Y Lines
  get gridYCount() {
    return this.args.gridYCount
      ? this.args.gridYCount
      : 10;
  }

  get dimensions() {
    if (this.args.dimensions) return this.args.dimensions
    return this.svg ? this.svg.getBoundingClientRect() : {};
  }

  // Computed Properties
  get hasGridX() {
    return this.xLineStyle !== 'none' && this.gridXLines;
  }

  get hasGridY() {
    return this.yLineStyle !== 'none' && this.gridYLines;
  }

  get gridXLines() {
    if (!this.svg) return []
    const divisionCount = this.gridXCount + (this.hasTopLine ? -1 : 0) + ((this.hasBottomLine ? 0 : 1));
    const divisions = this.dimensions.height / divisionCount;
    return Array.from(
      { length: this.gridXCount },
      (_, i) => Math.ceil(divisions * (this.hasTopLine ? i : i + 1)) + (i === this.gridXCount-1 ? -1 : 1)
    );
  }

  get gridYLines() {
    if (!this.svg) return [];
    const divisions = this.dimensions.width / this.gridYCount;
    return Array.from(
      { length: this.hasRightLine ? this.gridYCount : this.gridYCount - 1 },
      (_, i) => {
        return Math.ceil(divisions * (i + 1)) - this.strokeWidth
      }
    );
  }

  findSvg = (el) => {
    this.svg = el.closest('svg');
  }
}

==> sli-plots-0.0.29.tgz: package/addon/components/grid.js <==
import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';

export default class LineChartComponent extends Component {
  @tracked svg;

  // Required params
  // @dimensions

  // Parameters w/ defaults
  get hasTopLine() {
    return !!this.args.hasTopLine;
  }

  get excludeBottomXLine() {
    return !!this.args.excludeBottomXLine;
  }

  get excludeRightLine() {
    return !!this.args.excludeRightLine;
  }

  get excludeLeftLine() {
    return !!this.args.excludeLeftLine;
  }

  get xLineStyle() {
    return this.args.xLineStyle
      ? this.args.xLineStyle
      : 'solid';
  }

  get yLineStyle() {
    return this.args.yLineStyle
      ? this.args.yLineStyle
      : 'solid';
  }

  get strokeWidth() {
    return this.args.strokeWidth
      ? this.args.strokeWidth
      : '0.5';
  }

  get stroke() {
    return this.args.stroke
      ? this.args.stroke
      : 'lightgray';
  }

  get dashedSpacing() {
    return this.args.dashedSpacing
      ? this.args.dashedSpacing
      : '10,10';
  }

  // Number of X Lines
  get gridXCount() {
    return this.args.gridXCount
      ? this.args.gridXCount
      : 1;
  }

  // Number of Y Lines
  get gridYCount() {
    return this.args.gridYCount
      ? this.args.gridYCount
      : 10;
  }

  get dimensions() {
    if (this.args.dimensions) return this.args.dimensions
    return this.svg ? this.svg.getBoundingClientRect() : {};
  }

  // Computed Properties
  get hasGridX() {
    return this.xLineStyle !== 'none' && this.gridXLines;
  }

  get hasGridY() {
    return this.yLineStyle !== 'none' && this.gridYLines;
  }

  get gridXLines() {
    if (!this.svg) return []
    const divisionCount = this.gridXCount + (this.hasTopLine ? -1 : 0) + ((this.excludeBottomXLine ? 1 : 0));
    const divisions = this.dimensions.height / divisionCount;
    return Array.from(
      { length: this.gridXCount },
      (_, i) => Math.ceil(divisions * (this.hasTopLine ? i : i + 1)) + (i === this.gridXCount-1 ? -1 : 1)
    );
  }

  get gridYLines() {
    if (!this.svg) return [];
    const rightLineShift = this.excludeRightLine ? 0 : -1;
    const leftLineShift = this.excludeLeftLine ? 1 : 0;
    const divisions = this.dimensions.width / (this.gridYCount + rightLineShift + leftLineShift);
    return Array.from(
      { length: this.gridYCount },
      (_, i) => {
        return Math.ceil(divisions * (i + leftLineShift)) - this.strokeWidth
      }
    );
  }

  findSvg = (el) => {
    this.svg = el.closest('svg');
  }
}
